@@ -9,13 +9,16 @@ class AuthorizationDTO(object):
     def __init__(self, id: str, created_at: datetime, amount: int, card_last_4_digits: str, status: AuthorizationStatus,
                  merchant_name: str,
                  merchant_type: int, merchant_category: str, merchant_location: Optional[str], recurring: bool,
-                 tags: Optional[Dict[str, str]], relationships: Optional[Dict[str, Relationship]]):
+                 payment_method: Optional[str], digital_wallet: Optional[str], card_verification_data,
+                 card_network: Optional[str], tags: Optional[Dict[str, str]],
+                 relationships: Optional[Dict[str, Relationship]]):
         self.id = id
         self.type = "authorization"
         self.attributes = {"createdAt": created_at, "amount": amount, "cardLast4Digits": card_last_4_digits,
                            "status": status, "merchant": {"name": merchant_name, "type": merchant_type,
                                                           "category": merchant_category, "location": merchant_location},
-                           "recurring": recurring, "tags": tags}
+                           "recurring": recurring, "paymentMethod": payment_method, "digitalWallet": digital_wallet,
+                           "cardVerificationData": card_verification_data, "cardNetwork": card_network, "tags": tags}
         self.relationships = relationships
 
     @staticmethod
@@ -24,6 +27,8 @@ class AuthorizationDTO(object):
                                 attributes["cardLast4Digits"], attributes["status"], attributes["merchant"]["name"],
                                 attributes["merchant"]["type"], attributes["merchant"]["category"],
                                 attributes["merchant"].get("location"), attributes["recurring"],
+                                attributes.get("paymentMethod"), attributes.get("digitalWallet"),
+                                attributes.get("cardVerificationData"), attributes.get("cardNetwork"),
                                 attributes.get("tags"), relationships)
 
 
